/*
   (c)2014-2019 Forward Computing and Control Pty. Ltd.
   NSW Australia, www.forward.com.au
   This code is not warranted to be fit for any purpose. You may only use it at your own risk.
   This code may be freely used for both private and commercial use
   Provide this copyright is maintained.
*/

#include "Thermometer.h"

Thermometer::Thermometer(pfodDwgs *_dwgsPtr) : pfodControl(_dwgsPtr) {
  z_idx = pfodDwgs::reserveIdx(2); // z_idx for bar, z_idx+1 label
}

char Thermometer::getCmd() {
  return sliderCmd;
}

void Thermometer::draw() {
  dwgsPtr->pushZero(0, 0, 0.125);  // scale down 240 to 30 cols
  dwgsPtr->circle().filled().radius(10).color(dwgsPtr->RED).offset(0, 0).send();
  dwgsPtr->rectangle().filled().filled().color(dwgsPtr->GREY).size(1, -240).offset(-0.5, 0).send();

  dwgsPtr->label().fontSize(18).text("-10\342\204\203").color(dwgsPtr->RED).offset(40, 0).send();
  dwgsPtr->line().color(dwgsPtr->RED).offset( -7.5, 0).size( 15, 0).send();

  dwgsPtr->label().fontSize(18).text("50\342\204\203").color(dwgsPtr->RED).offset(30, -240).send();
  dwgsPtr->line().color(dwgsPtr->RED).offset( -7.5, -240).size( 15, 0).send();

  update(); // update with current state
  dwgsPtr->popZero();
}

void Thermometer::update() {
  int limitedValue = (value * 240) / RANGE;
  if (limitedValue < 0) {
    limitedValue = 0;
  }
  if (limitedValue > 240) {
    limitedValue = 240;
  }
  dwgsPtr->rectangle().filled().idx(z_idx).color(dwgsPtr->RED).size(5, -limitedValue).offset(-2.5, 0).send();
  dwgsPtr->label().idx(z_idx + 1).decimals(1).intValue(-value).units("\342\204\203").maxValue(-RANGE)
  .displayMax(MAX_C).displayMin(MIN_C).fontSize(28).bold().color(dwgsPtr->RED).offset(-75, -limitedValue).send();
}
